Alternative libraries
=====================

osmnx
-----

`https://github.com/gboeing/osmnx <https://github.com/gboeing/osmnx>`_

This library also downloads data from OpenStreetMap. They have a great added value for networks of streets/roads.
